@@ -15,7 +15,10 @@ from .tabs import Tabs
 from .dialog import Dialog
 from .splitters import HSplit, VSplit
 from .ifields import IText,ITextarea,IRange,IBool,ISelect,IRadios
-
+from .fileupload import FileUpload
+from .containers import VScroll,VScrollPager    
+from .sortables import Sortable
+from .swipers import Swiper
 class App(Tag.body):
     _ui=None
     
@@ -28,5 +31,7 @@ class App(Tag.body):
 # global methods
 from .flex import hflex,vflex  # utilities (Htag contructor methods)
 
+# Swiper not inluded by default !!!!!
 
-ALL=[App,Form,Tabs,Dialog,HSplit,VSplit,IText,ITextarea,IRange,IBool,ISelect,IRadios]
+ALL=[App,Form,Tabs,Dialog,HSplit,VSplit,IText,ITextarea,IRange,IBool,ISelect,IRadios,FileUpload,Sortable,VScroll,VScrollPager]
+FULL=ALL+[Swiper] # Swiper not inluded by default !!!!! (coz +170ko)
